import json
import os
import shutil
from jinja2 import Environment, FileSystemLoader, select_autoescape

GAME_PLAYLIST_FILE = "/disk1/chat_downloader/game_playlists.json"
SAVE_HTML_FOLDER = "/disk1/webserver/rabbalabs/vods/"

verbose_output = False


def main():
    env = Environment(
        loader=FileSystemLoader("playlist_maker/templates"),
        autoescape=select_autoescape(),
    )
    print("Generating playlists.")
    with open(GAME_PLAYLIST_FILE) as playlist_json:
        playlists = json.load(playlist_json)
    playlist_template = env.get_template("single_playlist.html")
    index_template = env.get_template("index.html")
    to_process = list(playlists.items())
    if to_process:
        playlists_dir = os.path.join(SAVE_HTML_FOLDER, "playlists")
        if os.path.isdir(playlists_dir):
            shutil.rmtree(playlists_dir)
        os.makedirs(playlists_dir, mode=0o755)
    for game_id, game_info in to_process:
        if verbose_output:
            print(
                f"Processing {game_info['title']} ({game_info['year']}) ({len(game_info['videos'])} items)"
            )
        game_info["videos"].sort(key=lambda i: i["timestamp"], reverse=True)
        save_location = os.path.join(playlists_dir, f"{game_id}.html")
        save_data = playlist_template.render(videos=game_info["videos"])
        with open(save_location, "w", encoding="utf-8") as save_html:
            save_html.write(save_data)
    to_process.sort(key=lambda i: i[1]["videos"][0]["timestamp"], reverse=True)
    save_location = os.path.join(SAVE_HTML_FOLDER, "index.html")
    save_data = index_template.render(playlists=to_process)
    with open(save_location, "w", encoding="utf-8") as save_html:
        save_html.write(save_data)
    print("Done.")


if __name__ == "__main__":
    verbose_output = True
    main()
